@@ -18,28 +18,34 @@
 
 #include "bluewizard.h"
 #include "wizardagent.h"
-#include "pages/introductionpage.h"
 #include "pages/discoverpage.h"
-#include "pages/pinpage.h"
-#include "pages/pairingpage.h"
 #include "pages/servicespage.h"
+#include "pages/nopairing.h"
+#include "pages/legacypairing.h"
+#include "pages/legacypairingdatabase.h"
+#include "pages/keyboardpairing.h"
+#include "pages/ssppairing.h"
+#include "pages/fail.h"
 #include "../actionplugins/actionplugin.h"
 
 #include <QApplication>
 #include <QDBusConnection>
 #include <QWizard>
+#include <QString>
 
 #include <bluedevil/bluedevil.h>
 #include <KServiceTypeTrader>
 #include <KPushButton>
 #include <kdebug.h>
+#include <KProcess>
 
 BlueWizard::BlueWizard(const KUrl &url) : QWizard(), m_service(0), m_manualPin(false)
 {
-    setWindowTitle(i18n("Bluetooth Remote Device Wizard"));
+    setWindowTitle(i18n("Bluetooth Device Wizard"));
+
+    setOption(QWizard::IndependentPages, true);
 
     if (url.host().length() != 17) {
-        setPage(Introduction, new IntroductionPage(this));
         setPage(Discover, new DiscoverPage(this));
     } else {
         setDeviceAddress(url.host().replace("-", ":").toLatin1());
@@ -48,19 +54,23 @@ BlueWizard::BlueWizard(const KUrl &url) : QWizard(), m_service(0), m_manualPin(f
     if (url.fileName().length() == 36) {
         setPreselectedUuid(url.fileName().toLatin1());
     }
-    setPage(Pin, new PinPage(this));
-    setPage(Pairing, new PairingPage(this));
+
     setPage(Services, new ServicesPage(this));
+    setPage(NoPairing, new NoPairingPage(this));
+    setPage(LegacyPairing, new LegacyPairingPage(this));
+    setPage(LegacyPairingDatabase, new LegacyPairingPageDatabase(this));
+    setPage(KeyboardPairing, new KeyboardPairingPage(this));
+    setPage(SSPPairing, new SSPPairingPage(this));
+    setPage(Fail, new FailPage(this));
 
     setButton(QWizard::BackButton, new KPushButton(KStandardGuiItem::back(KStandardGuiItem::UseRTL)));
     setButton(QWizard::NextButton, new KPushButton(KStandardGuiItem::forward(KStandardGuiItem::UseRTL)));
+    setButton(QWizard::FinishButton, new KPushButton(KStandardGuiItem::apply()));
     setButton(QWizard::CancelButton, new KPushButton(KStandardGuiItem::cancel()));
 
     //We do not want "Forward" as text
     setButtonText(QWizard::NextButton, i18nc("Action to go to the next page on the wizard", "Next"));
-
-    setButtonLayout(QList<QWizard::WizardButton>() << QWizard::CancelButton << QWizard::Stretch << QWizard::BackButton << QWizard::NextButton << QWizard::FinishButton);
-
+    setButtonText(QWizard::FinishButton, i18nc("Action to finish the wizard", "Finish"));
     //First show, then do the rest
     show();
 
@@ -114,28 +124,31 @@ QByteArray BlueWizard::deviceAddress() const
     return m_deviceAddress;
 }
 
+void BlueWizard::restartWizard()
+{
+    KProcess proc;
+    proc.setProgram("bluedevil-wizard");
+    proc.startDetached();
+
+    qApp->quit();
+}
+
 void BlueWizard::setPin(const QByteArray& pinNum)
 {
     kDebug() << "Setting pin: :" << pinNum;
     m_pin = pinNum;
 }
 
+void BlueWizard::setPin(const QString& pin)
+{
+    setPin(pin.toAscii());
+}
+
 QByteArray BlueWizard::pin() const
 {
     return m_pin;
 }
 
-void BlueWizard::setManualPin(bool pinManual)
-{
-    kDebug() << "Manual pin: " << pinManual;
-    m_manualPin = pinManual;
-}
-
-bool BlueWizard::manualPin() const
-{
-    return m_manualPin;
-}
-
 void BlueWizard::setPreselectedUuid(const QByteArray& uuid)
 {
     kDebug() << "Preselect UUID: " << uuid;
