@@ -20,6 +20,7 @@
 #include "discoverpage.h"
 #include "ui_discover.h"
 #include "../bluewizard.h"
+#include "../wizardagent.h"
 
 #include <QListWidgetItem>
 #include <QListView>
@@ -27,16 +28,21 @@
 #include <QTimer>
 
 #include <KDebug>
+#include <kpixmapsequenceoverlaypainter.h>
 
 #include <bluedevil/bluedevil.h>
 
 using namespace BlueDevil;
 
-DiscoverPage::DiscoverPage(QWidget* parent): QWizardPage(parent), m_wizard(0)
+DiscoverPage::DiscoverPage(BlueWizard* parent): QWizardPage(parent), m_wizard(parent)
 {
-    setTitle("Discover Devices");
+    setTitle(i18n("Select a device"));
     setupUi(this);
 
+    KPixmapSequenceOverlayPainter *workingPainter = new KPixmapSequenceOverlayPainter(this);
+    workingPainter->setWidget(working);
+    workingPainter->start();
+
     connect(deviceList, SIGNAL(itemActivated(QListWidgetItem*)), this,
             SLOT(itemSelected(QListWidgetItem*)));
 }
@@ -48,36 +54,46 @@ DiscoverPage::~DiscoverPage()
 void DiscoverPage::initializePage()
 {
     kDebug() << "Initialize Page";
-    if (!m_wizard) {
-        kDebug() << "First time in the page";
-        m_wizard = static_cast<BlueWizard* >(wizard());
-        connect(Manager::self()->defaultAdapter(), SIGNAL(deviceFound(QVariantMap)), this,
-            SLOT(deviceFound(QVariantMap)));
-    }
 
-    connect(m_wizard, SIGNAL(currentIdChanged(int)), this, SLOT(leavePage(int)));
+    QList <QWizard::WizardButton> list;
+    list << QWizard::Stretch;
+    list << QWizard::NextButton;
+    list << QWizard::CancelButton;
+    m_wizard->setButtonLayout(list);
+
+    connect(Manager::self()->defaultAdapter(), SIGNAL(deviceFound(QVariantMap)), this,
+        SLOT(deviceFound(QVariantMap)));
+    connect(manualPin, SIGNAL(toggled(bool)), pinText, SLOT(setEnabled(bool)));
+    connect(manualPin, SIGNAL(toggled(bool)), this, SIGNAL(completeChanged()));
+    connect(pinText, SIGNAL(textChanged(QString)), m_wizard, SLOT(setPin(QString)));
+    connect(pinText, SIGNAL(textChanged(QString)), this, SIGNAL(completeChanged()));
+
     startScan();
 }
 
-void DiscoverPage::leavePage(int id)
+void DiscoverPage::nameChanged(const QString& name)
 {
-    if (id == 2) {
-        cleanupPage();
+    kDebug() << name;
+    Device *device = static_cast<Device *>(sender());
+    m_itemRelation.value(device->address())->setText(name);
+    if (!device->name().isEmpty()) {
+        m_itemRelation[device->address()]->setText(device->friendlyName());
+        if (m_itemRelation[device->address()]->isSelected()) {
+            m_wizard->setDeviceAddress(device->address().toAscii());
+            emit completeChanged();
+        }
+        return;
     }
 }
 
-void DiscoverPage::cleanupPage()
-{
-    stopScan();
-    deviceList->clear();
-    m_itemRelation.clear();
-}
-
 bool DiscoverPage::isComplete() const
 {
     if (m_wizard->deviceAddress().isEmpty()) {
         return false;
     }
+    if (manualPin->isChecked() && pinText->text().isEmpty()) {
+        return false;
+    }
     return true;
 }
 
@@ -103,13 +119,6 @@ void DiscoverPage::deviceFound(const QVariantMap &deviceInfo)
     QString icon = deviceInfo["Icon"].toString();
     QString alias = deviceInfo["Alias"].toString();
 
-    kDebug() << "========================";
-    kDebug() << "Address: " << address;
-    kDebug() << "Name: " << name;
-    kDebug() << "Alias: " << alias;
-    kDebug() << "Icon: " << icon;
-    kDebug() << "\n";
-
     bool origName = false;
     if (!name.isEmpty()) {
         origName = true;
@@ -160,14 +169,60 @@ void DiscoverPage::itemSelected(QListWidgetItem* item)
 
 int DiscoverPage::nextId() const
 {
-    if (m_wizard) {
-        if (!m_wizard->deviceAddress().isEmpty()) {
-            Device *device = Manager::self()->defaultAdapter()->deviceForAddress(m_wizard->deviceAddress());
-            if (device->isPaired()) {
-                kDebug() << "Device is paired, jumping";
-                return BlueWizard::Services;
-            }
-        }
+    kDebug();
+    if (!isComplete()) {
+        return BlueWizard::Discover;
+    }
+
+    if (!m_wizard) {
+        return BlueWizard::Discover;
+    }
+
+    if (m_wizard->deviceAddress().isEmpty()) {
+        return BlueWizard::Discover;
+    }
+
+    kDebug() << "Stopping scanning";
+
+    Manager::self()->defaultAdapter()->stopDiscovery();
+    Device *device = Manager::self()->defaultAdapter()->deviceForAddress(m_wizard->deviceAddress());
+    if (device->isPaired()) {
+        kDebug() << "Device is paired, jumping";
+        return BlueWizard::Services;
+    }
+
+    QString pin;
+    if (manualPin->isChecked()) {
+        pin = m_wizard->pin();
+        m_wizard->agent()->setPin(pin);
+    } else {
+        pin = m_wizard->agent()->getPin(device);
+    }
+
+    kDebug() << "Class: " << classToType(device->deviceClass());
+    kDebug() << "Legacy: " << device->hasLegacyPairing();
+    kDebug() << "From DB: " << m_wizard->agent()->isFromDatabase();
+    kDebug() << "PIN: " << m_wizard->agent()->pin();
+
+    //If pin ==  NULL means that not pairing is required
+    if (!device->hasLegacyPairing() && !m_wizard->agent()->isFromDatabase()) {
+        kDebug() << "Secure Pairing";
+        return BlueWizard::SSPPairing;
+    }
+
+    if (pin == "NULL") {
+        kDebug() << "NO Pairing";
+        return BlueWizard::NoPairing;
+    }
+
+    if (classToType(device->deviceClass()) == BLUETOOTH_TYPE_KEYBOARD) {
+        kDebug() << "Keyboard Pairing";
+        return BlueWizard::KeyboardPairing;
+    }
+
+    if (m_wizard->agent()->isFromDatabase()) {
+        return BlueWizard::LegacyPairingDatabase;
+    } else {
+        return BlueWizard::LegacyPairing;
     }
-    return BlueWizard::Pin;
 }
